# Copyright (c)2011-2012 the Boeing Company.
# See the LICENSE file included in this directory.

"""corens3

Python package containing CORE components for use 
with the ns-3 simulator.

See http://www.nrl.navy.mil/itd/ncs/products/core and
http://code.google.com/p/coreemu/ for more information on CORE.

Pieces can be imported individually, for example

    import corens3

or everything listed in __all__ can be imported using

    from corens3 import *
"""

__all__ = []

